#!/usr/bin/env python
# -*- coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta
from __future__ import print_function
from __future__ import unicode_literals
from __future__ import absolute_import
from __future__ import division

from ionas.request import Request, Entry, EntryList, XmlConfNode
from product_conf import SUDO_CMD


def send_entry(falcmd, entry, raise_exception=False):
    try:
        entrylist = EntryList()
        entrylist.append_entry(entry)
        req = Request(falcmd, filter_cmd=SUDO_CMD)
        res = req.request(entrylist)
        return res.get_entrylist().get_entry()
    except Exception as e:
        if raise_exception:
            raise
        return None


def gettext(constname, arglist={}, default='', raise_exception=False):
    try:
        from fal_msginfo import Msg
        from fal_info import FAL_MESSAGES_PATH
        code = getattr(Msg, constname)
        entry = Entry('query', """<messages>
            <messageinfo>
                <code />
                <arglist />
            </messageinfo>
        </messages>""")
        messages_node = entry.get()
        code_node = messages_node.get_node('messageinfo/code')
        arglist_node = messages_node.get_node('messageinfo/arglist')
        code_node.set_text(code)
        for k, v in arglist.iteritems():
            arglist_node.append_child('arg', text=v, attrs={'name': k})
        entry = send_entry(
            FAL_MESSAGES_PATH,
            entry,
            raise_exception=raise_exception,
        )
        return entry.get().get_value('messageinfo/message', default)
    except Exception as e:
        if raise_exception:
            raise
        return default


def logging(constname, arglist={}, raise_exception=False):
    try:
        from fal_info import FAL_EVENTLOG_PATH
        from fal_info import Results
        code = getattr(Msg, constname)
        entry = Entry('add', """<eventlog>
            <log>
                <code />
                <arglist />
            </log>
        </eventlog>""")
        eventlog_node = entry.get()
        code_node = eventlog_node.get_node('log/code')
        arglist_node = eventlog_node.get_node('log/arglist')
        code_node.set_text(code)
        for k, v in arglist.iteritems():
            arglist_node.append_child('arg', text=v, attrs={'name': k})
        entry = send_entry(
            FAL_EVENTLOG_PATH,
            entry,
            raise_exception=raise_exception,
        )
        if entry.get_result() not in (Results.OK,):
            raise
    except Exception as e:
        if raise_exception:
            raise
